@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Copyright 2024 Univention GmbH
 #
@@ -71,7 +70,7 @@ def test_file(parse, tmplog):
 @pytest.mark.parametrize('function,expected', [(ud.FUNCTION, ['init', 'begin', 'end', 'exit']), (ud.NO_FUNCTION, ['init', 'exit'])])
 def test_function(function, expected, parse, tmplog):
     def f():
-        _d = ud.function('f')  # noqa: F841
+        _d = ud.function('f')
         _d  # noqa: B018
 
     ud.set_function(function)
@@ -142,13 +141,13 @@ def test_reopen(parse, tmplog):
 
 
 def test_unicode(parse, tmplog):
-    ud.debug(ud.MAIN, ud.ERROR, u'\u2603' if sys.getdefaultencoding() != 'ascii' else u'\u2603'.encode())
+    ud.debug(ud.MAIN, ud.ERROR, '\u2603' if sys.getdefaultencoding() != 'ascii' else '\u2603'.encode())
     ud.exit()
 
     output = tmplog.read()
     for ((c_type, c_groups), (e_type, e_groups)) in zip(parse(output), [
             ('init', {}),
-            ('msg', {'msg': '\xe2\x98\x83' if sys.version_info.major < 3 else u'\u2603'}),
+            ('msg', {'msg': '\xe2\x98\x83' if sys.version_info.major < 3 else '\u2603'}),
             ('exit', {}),
     ]):
         assert c_type == e_type
