@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Copyright 2024 Univention GmbH
 #
@@ -34,6 +33,7 @@
 
 import re
 import sys
+from collections.abc import Callable, Iterator
 from datetime import datetime
 from logging import DEBUG
 
@@ -42,12 +42,6 @@ import pytest
 import univention.debug2 as ud
 
 
-try:
-    from typing import Callable, Dict, Iterator, Tuple  # noqa: F401
-except ImportError:
-    pass
-
-
 RE = re.compile(
     r'''
     (?P<datetime>[0-3]\d\.[01]\d\.\d{4}\s[0-2]\d:[0-5]\d:[0-5]\d)\.(?P<msec>\d{3})\s(?P<category>\S+)\s+\((?P<level>\S+)\s*\):\s(?P<text>
@@ -84,14 +78,12 @@ CATEGORY = [
 
 
 @pytest.fixture()
-def parse():
-    # type: () -> Iterator[Callable[[str], Iterator[Tuple[str, Dict[str, str]]]]]
+def parse() -> Iterator[Callable[[str], Iterator[tuple[str, dict[str, str]]]]]:
     """Setup parser."""
     now = datetime.now()
     start = now.replace(microsecond=now.microsecond - now.microsecond % 1000)
 
-    def f(text):
-        # type: (str) -> Iterator[Tuple[str, Dict[str, str]]]
+    def f(text: str) -> Iterator[tuple[str, dict[str, str]]]:
         """
         Parse line into componets.
 
@@ -158,7 +150,7 @@ def test_file(parse, tmplog):
 @pytest.mark.parametrize('function,expected', [(ud.FUNCTION, ['init', 'begin', 'end', 'exit']), (ud.NO_FUNCTION, ['init', 'exit'])])
 def test_function(function, expected, parse, tmplog):
     def f():
-        _d = ud.function('f')  # noqa: F841
+        _d = ud.function('f')
         _d  # noqa: B018
 
     ud.set_function(function)
@@ -230,13 +222,13 @@ def test_reopen(parse, tmplog):
 
 
 def test_unicode(parse, tmplog):
-    ud.debug(ud.MAIN, ud.ERROR, u'\u2603')
+    ud.debug(ud.MAIN, ud.ERROR, '\u2603')
     ud.exit()
 
     output = tmplog.read()
     for ((c_type, c_groups), (e_type, e_groups)) in zip(parse(output), [
             ('init', {}),
-            ('msg', {'msg': '\xe2\x98\x83' if sys.version_info.major < 3 else u'\u2603'}),
+            ('msg', {'msg': '\xe2\x98\x83' if sys.version_info.major < 3 else '\u2603'}),
             ('exit', {}),
     ]):
         assert c_type == e_type
